@@ -1,11 +1,4 @@
-from convert_to_onnx import ConvertToOnnx
-
-try:
-    import onnx
-    from onnx_tf.backend import prepare
-except ImportError:
-    raise ImportError(f"You need to install ONNX and ONNX_TF to convert a model to \
-            TensorFlow/Keras format")
+from .convert_to_onnx import ConvertToOnnx
 
 class ConvertToTF():
     def __init__(self, onnx_model_name=False, tf_model_name=False):
@@ -22,6 +15,11 @@ class ConvertToTF():
         return self.converted_model
 
     def convert(model):
+        try:
+            from onnx_tf.backend import prepare
+        except ImportError:
+            raise ImportError(f"You need to install ONNX and ONNX_TF to convert a model to TensorFlow/Keras format")
+
         if model.type=='pytorch':
             return self._convert_pytorch_model(model)
         else:
